@@ -1,11 +1,13 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from threading import Lock, Thread
+from threading import Lock
 
 from gi.repository import GLib, Gtk
 
+from .buttons import ContinueButton
 from .config import config
-from .system_calls import open_wifi_settings, start_system_timesync
+from .system_calls import start_system_timesync
+from .translations import translate_widgets
 
 
 @Gtk.Template(resource_path='/com/github/p3732/os-installer/ui/pages/internet.ui')
@@ -13,8 +15,15 @@ class InternetPage(Gtk.Stack):
     __gtype_name__ = __qualname__
     image = 'network-wireless-disabled-symbolic'
 
+    no_connection_label = Gtk.Template.Child()
+    settings_button = Gtk.Template.Child()
+    yes_connection_label = Gtk.Template.Child()
+
     def __init__(self, **kwargs):
-        Gtk.Stack.__init__(self, **kwargs)
+        super().__init__(**kwargs)
+
+        translate_widgets(self.no_connection_label, self.settings_button,
+                          self.yes_connection_label)
 
         self.update_lock = Lock()
         self.has_advanced = False
@@ -23,14 +32,10 @@ class InternetPage(Gtk.Stack):
 
     ### callbacks ###
 
-    @Gtk.Template.Callback('clicked_settings_button')
-    def _clicked_settings_button(self, button):
-        open_wifi_settings()
-
     def _connection_state_changed(self, connected):
         with self.update_lock:
             if connected:
-                GLib.idle_add(self.set_visible_child_name, 'connected')
+                GLib.idle_add(self._ui_change_stack, 'connected')
                 config.set('internet_page_image',
                            'network-wireless-symbolic')
                 start_system_timesync()
@@ -38,10 +43,10 @@ class InternetPage(Gtk.Stack):
                     self.has_advanced = True
                     GLib.idle_add(config.set_next_page, self)
             else:
-                GLib.idle_add(self.set_visible_child_name, 'not-connected')
+                GLib.idle_add(self._ui_change_stack, 'not-connected')
                 config.set('internet_page_image',
                            'network-wireless-disabled-symbolic')
 
-    @Gtk.Template.Callback('continue')
-    def _continue(self, object):
-        config.set_next_page(self)
+    def _ui_change_stack(self, name):
+        self.set_visible_child_name(name)
+        return False
