@@ -10,13 +10,13 @@ from .preloadable import Preloadable
 
 class InternetProvider(Preloadable):
     def __init__(self):
-        Preloadable.__init__(self, self._run_connection_checker)
+        super().__init__(self._run_connection_checker)
 
     def _run_connection_checker(self):
         Thread(target=self._check_connection, daemon=True).start()
 
     def _check_connection(self):
-        url = config.get('internet_checker_url')
+        url = config.get('internet')['checker_url']
 
         while not config.get('installation_running'):
             try:
