@@ -1,8 +1,5 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from threading import Lock
-import os
-
 from gi.repository import GObject, GnomeDesktop
 
 from .config import config
@@ -33,7 +30,7 @@ language_to_default_locale = {
     'ne': 'ne_NP.UTF-8', 'ng_NG': 'en_NG.UTF-8', 'nb': 'nb_NO.UTF-8', 'nn': 'nn_NO.UTF-8', 'no': 'no_NO.UTF-8',
     'nr': 'nr_ZA.UTF-8', 'oc': 'oc_FR.UTF-8', 'cu_CU': 'es_CU.UTF-8', 'om': 'om_ET.UTF-8', 'or': 'or_IN.UTF-8',
     'os': 'os_RU.UTF-8', 'pa': 'pa_IN.UTF-8', 'fa': 'fa_IR.UTF-8', 'pl': 'pl_PL.UTF-8', 'ps': 'ps_AF.UTF-8',
-    'pt': 'pt_BR.UTF-8', 'ro': 'ro_RO.UTF-8', 'ru': 'ru_RU.UTF-8', 'sa': 'sa_IN.UTF-8', 'sc': 'sc_IT.UTF-8',
+    'pt': 'pt_PT.UTF-8', 'ro': 'ro_RO.UTF-8', 'ru': 'ru_RU.UTF-8', 'sa': 'sa_IN.UTF-8', 'sc': 'sc_IT.UTF-8',
     'sd': 'sd_IN.UTF-8', 'se': 'se_NO.UTF-8', 'sm': 'sm_WS.UTF-8', 'sg_SG': 'en_SG.UTF-8', 'sr': 'sr_RS.UTF-8',
     'gd': 'gd_GB.UTF-8', 'sn_SN': 'wo_SN.UTF-8', 'si': 'si_LK.UTF-8', 'sk': 'sk_SK.UTF-8', 'sl': 'sl_SI.UTF-8',
     'so': 'so_SO.UTF-8', 'st': 'st_ZA.UTF-8', 'es': 'es_ES.UTF-8', 'sw': 'sw_KE.UTF-8', 'ss': 'ss_ZA.UTF-8',
@@ -43,6 +40,7 @@ language_to_default_locale = {
     'ug': 'ug_CN.UTF-8', 'uk': 'uk_UA.UTF-8', 'ur': 'ur_PK.UTF-8', 'uz': 'uz_UZ.UTF-8@cyrillic', 've': 've_ZA.UTF-8',
     'vi': 'vi_VN.UTF-8', 'wa': 'wa_BE.UTF-8', 'cy': 'cy_GB.UTF-8', 'wo': 'wo_SN.UTF-8', 'fy': 'fy_NL.UTF-8',
     'xh': 'xh_ZA.UTF-8', 'yi': 'yi_US.UTF-8', 'yo': 'yo_NG.UTF-8', 'za_ZA': 'zu_ZA.UTF-8', 'zu': 'zu_ZA.UTF-8',
+    'kab': 'kab_DZ.UTF-8',
     # manually added
     'pt_BR': 'pt_BR.UTF-8', 'pt_PT': 'pt_PT.UTF-8',
 }
@@ -50,61 +48,73 @@ language_to_default_locale = {
 
 class LanguageInfo(GObject.Object):
     __gtype_name__ = __qualname__
-    name: str
-    language_code: str
-    locale: str
 
-    def __init__(self, name, language_code, locale):
+    def __init__(self, name, code, locale, available=True):
         super().__init__()
 
-        self.name = name
-        self.language_code = language_code
+        self.available = available
+        self.code = code
         self.locale = locale
+        self.name = name
 
 
 class LanguageProvider(Preloadable):
     def __init__(self):
-        Preloadable.__init__(self, self._get_languages)
+        super().__init__(self._get_languages)
 
-    def _get_default_locale(self, language):
-        if language in language_to_default_locale:
-            return language_to_default_locale[language]
+        future = self.thread_pool.submit(self._determine_fixed_language)
+        config.set('language_use_fixed', future)
+
+    def _determine_fixed_language(self):
+        fixed_language = config.get('fixed_language')
+        if not fixed_language:
+            return False
+
+        if fixed_info := self._create_info(fixed_language):
+            config.set('language_chosen', fixed_info)
+            return True
         else:
-            return "C"
+            print('Distribution developer hint: Fixed language '
+                  f'{fixed_language} is not available in current system. '
+                  'Falling back to default language selection.')
+            config.set('fixed_language', False)
+            return False
 
-    def _get_existing_translations(self, localedir):
-        # English always exists
-        existing_translations = {'en'}
+    def _create_info(self, language_code):
+        locale = language_to_default_locale.get(language_code, None)
+        if not locale and '_' in language_code:
+            # already has territory, use as-is
+            locale = f'{language_code}.UTF-8'
+        elif not locale:
+            print(f"Can't determine locale for {language_code}")
+            return None
 
-        # check what translations exist in the locale folder
-        for file in os.scandir(localedir):
-            if file.is_dir():
-                locale_folder = os.path.join(file.path, 'LC_MESSAGES')
-                if os.path.isdir(locale_folder):
-                    for locale_file in os.scandir(locale_folder):
-                        if locale_file.name == 'os-installer.mo':
-                            language = os.path.basename(file.path)
-                            existing_translations.add(language)
-        return existing_translations
+        if name := GnomeDesktop.get_language_from_locale(locale, locale):
+            return LanguageInfo(name, language_code, locale)
+        elif name := GnomeDesktop.get_language_from_locale(locale):
+            return LanguageInfo(name, language_code, locale, False)
 
-    def _get_language_name_localized(self, lang_locale, localization, lang_code):
-        if name := GnomeDesktop.get_language_from_locale(lang_locale, localization):
-            return name
-        elif lang := GnomeDesktop.get_language_from_code(lang_code.split('_')[0], localization):
-            return f'{lang} ({lang_code})'
+        national_code = language_code.split('_')[0]
+        if lang := GnomeDesktop.get_language_from_code(national_code, locale):
+            name = f'{lang} ({language_code})'
+            return LanguageInfo(name, language_code, locale)
+        elif lang := GnomeDesktop.get_language_from_code(national_code):
+            name = f'{lang} ({language_code})'
+            return LanguageInfo(name, language_code, locale, False)
 
     def _get_languages(self):
-        localedir = config.get('localedir')
-        translations = self._get_existing_translations(localedir)
+        # Assure that some language is set in testing mode
+        if not config.has('language_chosen'):
+            english_info = self._create_info('en')
+            config.set('language_chosen', english_info)
+
+        translations = config.get('available_translations')
 
         self.all_languages = []
         unavailable_languages = []
         for language_code in translations:
-            locale = self._get_default_locale(language_code)
-
-            if name := self._get_language_name_localized(locale, locale, language_code):
-                language_info = LanguageInfo(name, language_code, locale)
-                self.all_languages.append(language_info)
+            if info := self._create_info(language_code):
+                self.all_languages.append(info)
             else:
                 unavailable_languages.append(language_code)
 
@@ -113,44 +123,15 @@ class LanguageProvider(Preloadable):
                   sorted(unavailable_languages))
         self.all_languages.sort(key=lambda k: k.name)
 
-        self.suggested = []
-        self.other = []
-        suggested_codes = config.get('suggested_languages')
-        if suggested_codes and len(suggested_codes) > 0:
-            for language_info in self.all_languages:
-                if language_info.language_code in suggested_codes:
-                    self.suggested.append(language_info)
-                else:
-                    self.other.append(language_info)
-        else:
-            self.other = self.all_languages
-
     ### public methods ###
 
     def get_all_languages(self):
         self.assert_preloaded()
         return self.all_languages
 
-    def get_fixed_language(self, fixed_language):
+    def get_available_languages(self):
         self.assert_preloaded()
-
-        fixed = [info for info in self.all_languages
-                 if info.language_code == fixed_language]
-        if len(fixed) == 1:
-            return fixed[0]
-        else:
-            print('Distribution developer hint: Fixed language '
-                  f'{fixed_language} is not available in current system. '
-                  'Falling back to default language selection.')
-            return None
-
-    def get_suggested_languages(self):
-        self.assert_preloaded()
-        return self.suggested
-
-    def get_other_languages(self):
-        self.assert_preloaded()
-        return self.other
+        return self.all_languages
 
 
 language_provider = LanguageProvider()
