@@ -1,10 +1,10 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from pathlib import Path
-
 from gi.repository import Gtk
 
+from .buttons import ContinueButton
 from .config import config
+from .translator import config_gettext as _
 from .welcome_provider import welcome_provider
 
 
@@ -16,24 +16,15 @@ class WelcomePage(Gtk.Box):
     description = Gtk.Template.Child()
 
     def __init__(self, **kwargs):
-        Gtk.Box.__init__(self, **kwargs)
-
-        welcome = config.get('welcome_page')
-        language_code = config.get('language')[0]
-
-        if (text_key := f'text_{language_code}') in welcome:
-            text = welcome[text_key]
-        elif welcome['text']:
-            text = welcome['text']
-        else:
-            text = self.description.get_label()
-            text = text.format(config.get('distribution_name'))
-        self.description.set_label(text)
+        super().__init__(**kwargs)
 
         welcome_provider.assert_preloaded()
 
-    ### callbacks ###
+        welcome = config.get('welcome_page')
 
-    @Gtk.Template.Callback('continue')
-    def _continue(self, button):
-        config.set_next_page(self)
+        if text := welcome.get('text', None):
+            text = _(text)
+        else:
+            text = _(self.description.get_label())
+            text = text.format(config.get('distribution_name'))
+        self.description.set_label(text)
